Calculates daily log returns from the adjusted closing price column
produced by get_stock_prices(). Validates input and handles edge cases.
Arguments
- prices
A tibble returned by
get_stock_prices().
Calculates daily log returns from the adjusted closing price column
produced by get_stock_prices(). Validates input and handles edge cases.
A tibble returned by get_stock_prices().