Custom reactable theme for stocktipr6
Source:R/utils_reactable_theme.R
stocktipr6_reactable_theme.RdCreates a dark theme for reactable tables matching the stocktipr6 terminal aesthetic.
Value
A reactable::reactableTheme() object
R/utils_reactable_theme.R
stocktipr6_reactable_theme.RdCreates a dark theme for reactable tables matching the stocktipr6 terminal aesthetic.
A reactable::reactableTheme() object